==> furnace-0.6.7.tgz: share/doc/furnace/doc/7-systems/README.md <==
# systems

this is a list that contains some of the systems that Furnace supports, as shown in the New File dialog. each chip links to a page with information and a list of supported effects.

some systems have alternate chips, such as the Sega Genesis having a YM2612 or YM3438 depending on the model. this list shows the default configuration.

- **Sega Genesis**: [YM3438](ym2612.md), [SN76489](sms.md)
- **Sega Genesis (with Sega CD)**: [YM3438](ym2612.md), [SN76489](sms.md), [RF5C164](ricoh.md)
<!-- -->
- **Sega Master System**: [SN76489](sms.md)
- **Sega Master System (with FM expansion)**: [SN76489](sms.md), [YM2413](opll.md)
<!-- -->
- **NES**: [2A03](nes.md)
- **Famicom with Konami VRC6**: [2A03](nes.md), [VRC6](vrc6.md)
- **Famicom with Konami VRC7**: [2A03](nes.md), [VRC7](opl.md)
- **Famicom with MMC5**: [2A03](nes.md), [MMC5](mmc5.md)
- **Famicom with Sunsoft 5B**: [2A03](nes.md), [5B](ay8910.md)
- **Famicom with Namco 163**: [2A03](nes.md), [N163](n163.md)
- **Famicom Disk System**: [2A03](nes.md), [FDS](fds.md)
<!-- -->
- **Game Boy**: [Game Boy](game-boy.md)
<!-- -->
- **SNES**: [SNES](snes.md)
<!-- -->
- **NEC PC Engine/TurboGrafx-16**: [HuC6280](pce.md)
<!-- -->
- **Commodore VIC-20**: [VIC](vic20.md)
<!-- -->
- **Commodore 64 (6581 SID)**: [MOS 6581](c64.md)
- **Commodore 64 (8580 SID)**: [MOS 8580](c64.md)
<!-- -->
- **Amiga**: [Amiga](amiga.md)
<!-- -->
- **Arcade (YM2151 and SegaPCM)**: [YM2151](ym2151.md), [SegaPCM](segapcm.md)
<!-- -->
- **Capcom CPS-1**: [YM2151](ym2151.md), [MSM6295](msm6295.md)
- **Capcom CPS-2 (QSound)**: [QSound](qsound.md)
<!-- -->
- **Neo Geo CD**: [YM2610](ym2610.md)
- **Neo Geo CD (extended channel 2)**: [YM2610](ym2610.md)
<!-- -->
- **Neo Geo Pocket**: [T6W28](t6w28.md), [DAC](dac.md)
<!-- -->
- **Atari 2600/7800**: [TIA](tia.md)
- **Atari 800**: [POKEY](pokey.md)
<!-- -->
- **Konami Bubble System**: [AY-3-8910](ay8910.md) × 2, [Konami WSG](bubblesystem.md)
<!-- -->
- **Sharp X68000**: [YM2151](ym2151.md), [MSM6258](msm6258.md)
<!-- -->
- **PC + Sound Blaster Pro**: [YM3812](opl.md) × 2, [DAC](dac.md), [PC Speaker](pcspkr.md)
<!-- -->
- **MSX**: [AY-3-8910](ay8910.md)
- **MSX + SCC**: [YM2149(F)](ay8910.md), [SCC](scc.md)
<!-- -->
- **Commander X16 (VERA only)**: [VERA](vera.md)
<!-- -->
- and many, many more!



## chips

this is the full list of chips that Furnace supports.

- [2A03](nes.md)
- [5E01](5e01.md)
- [Amiga](amiga.md)
- [AY-3-8910/8914/YM2149(F)/Sunsoft 5B](ay8910.md)
- [Microship AY8930](ay8930.md)
- [Bifurcator](bifurcator.md)
- [MOS 6581/8580 (SID)](c64.md)
- [Dave](dave.md)
- [Ensoniq ES5506](es5506.md)
- [Konami SCC](scc.md)
- [FDS](fds.md)
- [Game Boy](game-boy.md)
- [Game Boy Advance](gba.md)
- [Generic PCM DAC](dac.md)
- [Irem GA20](ga20.md)
- [Bubble System WSG](bubblesystem.md)
- [K007232](k007232.md)
- [K053260](k056320.md)
- [Lynx](lynx.md)
- [MMC5](mmc5.md)
- [MSM5232](msm5232.md)
- [MSM6258](msm6258.md)
- [MSM6295](msm6295.md)
- [Namco 163](n163.md)
- [Namco C140](c140.md)
- [Namco WSG/C15/C30](namco.md)
- [Nintendo DS](nds.md)
- [HuC6280](pce.md)
- [PC Speaker](pcspkr.md)
- [PET](pet.md)
- [Pokémon Mini](pokemini.md)
- [POKEY](pokey.md)
- [PowerNoise](powernoise.md)
- [PV-1000](pv1000.md)
- [QSound](qsound.md)
- [RF5C68/RF5C164](ricoh.md)
- [SAA1099](saa1099.md)
- [SegaPCM](segapcm.md)
- [SID2](sid2.md)
- [SM8521](sm8521.md)
- [SN76489/Sega PSG](sms.md)
- [SNES](snes.md)
- [tildearrow Sound Unit](soundunit.md)
- [T6W28](t6w28.md)
- [TED](ted.md)
- [TIA](tia.md)
- [VERA](vera.md)
- [VIC](vic20.md)
- [Virtual Boy](virtual-boy.md)
- [VRC6](vrc6.md)
- [WonderSwan](wonderswan.md)
- [X1-010](x1-010.md)
- [Y8950, YM3526, YM3812 and YMF262 (OPL)](opl.md)
- [ESFM](esfm.md)
- [VRC7 and YM2413 (OPLL)](opll.md)
- [YM2414 (OPZ)](opz.md)
- [YM2151 (OPM)](ym2151.md)
- [YM2203 (OPN)](ym2203.md)
- [YM2608 (OPNA)](ym2608.md)
- [YM2610 (OPNB)](ym2610.md)
- [YM2610B (OPNB2)](ym2610b.md)
- [YM2612/YM3438 (OPN2)](ym2612.md)
- [YMZ280B](ymz280b.md)
- [ZX Spectrum Beeper](zxbeep.md)

Furnace also reads .dmf files with the [Yamaha YMU759](ymu759.md) system, but...

==> furnace-0.6.8.3.tgz: share/doc/furnace/doc/7-systems/README.md <==
# systems

this is a list that contains some of the systems that Furnace supports, as shown in the New File dialog. each chip links to a page with information and a list of supported effects.

some systems have alternate chips, such as the Sega Genesis having a YM2612 or YM3438 depending on the model. this list shows the default configuration.

- **Sega Genesis**: [YM3438](ym2612.md), [SN76489](sms.md)
- **Sega Genesis (with Sega CD)**: [YM3438](ym2612.md), [SN76489](sms.md), [RF5C164](ricoh.md)
<!-- -->
- **Sega Master System**: [SN76489](sms.md)
- **Sega Master System (with FM expansion)**: [SN76489](sms.md), [YM2413](opll.md)
<!-- -->
- **NES**: [2A03](nes.md)
- **Famicom with Konami VRC6**: [2A03](nes.md), [VRC6](vrc6.md)
- **Famicom with Konami VRC7**: [2A03](nes.md), [VRC7](opll.md)
- **Famicom with MMC5**: [2A03](nes.md), [MMC5](mmc5.md)
- **Famicom with Sunsoft 5B**: [2A03](nes.md), [5B](ay8910.md)
- **Famicom with Namco 163**: [2A03](nes.md), [N163](n163.md)
- **Famicom Disk System**: [2A03](nes.md), [FDS](fds.md)
<!-- -->
- **Game Boy**: [Game Boy](game-boy.md)
<!-- -->
- **SNES**: [SNES](snes.md)
<!-- -->
- **NEC PC Engine/TurboGrafx-16**: [HuC6280](pce.md)
<!-- -->
- **Commodore VIC-20**: [VIC](vic20.md)
<!-- -->
- **Commodore 64 (6581 SID)**: [MOS 6581](c64.md)
- **Commodore 64 (8580 SID)**: [MOS 8580](c64.md)
<!-- -->
- **Amiga**: [Amiga](amiga.md)
<!-- -->
- **Arcade (YM2151 and SegaPCM)**: [YM2151](ym2151.md), [SegaPCM](segapcm.md)
<!-- -->
- **Capcom CPS-1**: [YM2151](ym2151.md), [MSM6295](msm6295.md)
- **Capcom CPS-2 (QSound)**: [QSound](qsound.md)
<!-- -->
- **Neo Geo CD**: [YM2610](ym2610.md)
- **Neo Geo CD (extended channel 2)**: [YM2610](ym2610.md)
<!-- -->
- **Neo Geo Pocket**: [T6W28](t6w28.md), [DAC](dac.md)
<!-- -->
- **Atari 2600/7800**: [TIA](tia.md)
- **Atari 800**: [POKEY](pokey.md)
<!-- -->
- **Konami Bubble System**: [AY-3-8910](ay8910.md) × 2, [Konami WSG](bubblesystem.md)
<!-- -->
- **Sharp X68000**: [YM2151](ym2151.md), [MSM6258](msm6258.md)
<!-- -->
- **PC + Sound Blaster Pro**: [YM3812](opl.md) × 2, [DAC](dac.md), [PC Speaker](pcspkr.md)
<!-- -->
- **MSX**: [AY-3-8910](ay8910.md)
- **MSX + SCC**: [YM2149(F)](ay8910.md), [SCC](scc.md)
<!-- -->
- **Commander X16 (VERA only)**: [VERA](vera.md)
<!-- -->
- and many, many more!



## chips

this is the full list of chips that Furnace supports.

- [2A03](nes.md)
- [5E01](5e01.md)
- [Amiga](amiga.md)
- [AY-3-8910/8914/YM2149(F)/Sunsoft 5B](ay8910.md)
- [Microchip AY8930](ay8930.md)
- [Bifurcator](bifurcator.md)
- [MOS 6581/8580 (SID)](c64.md)
- [Dave](dave.md)
- [Ensoniq ES5506](es5506.md)
- [Konami SCC](scc.md)
- [FDS](fds.md)
- [Game Boy](game-boy.md)
- [Game Boy Advance](gba.md)
- [Generic PCM DAC](dac.md)
- [Irem GA20](ga20.md)
- [Bubble System WSG](bubblesystem.md)
- [K007232](k007232.md)
- [K053260](k056320.md)
- [Lynx](lynx.md)
- [MMC5](mmc5.md)
- [MSM5232](msm5232.md)
- [MSM6258](msm6258.md)
- [MSM6295](msm6295.md)
- [Namco 163](n163.md)
- [Namco C140](c140.md)
- [Namco WSG/C15/C30](namco.md)
- [Nintendo DS](nds.md)
- [HuC6280](pce.md)
- [PC Speaker](pcspkr.md)
- [PET](pet.md)
- [Pokémon Mini](pokemini.md)
- [POKEY](pokey.md)
- [PowerNoise](powernoise.md)
- [PV-1000](pv1000.md)
- [QSound](qsound.md)
- [RF5C68/RF5C164](ricoh.md)
- [SAA1099](saa1099.md)
- [SegaPCM](segapcm.md)
- [SID2](sid2.md)
- [SID3](sid3.md)
- [SM8521](sm8521.md)
- [SN76489/Sega PSG](sms.md)
- [SNES](snes.md)
- [tildearrow Sound Unit](soundunit.md)
- [T6W28](t6w28.md)
- [TED](ted.md)
- [TIA](tia.md)
- [VERA](vera.md)
- [VIC](vic20.md)
- [Virtual Boy](virtual-boy.md)
- [VRC6](vrc6.md)
- [Watara Supervision](watarasv.md)
- [WonderSwan](wonderswan.md)
- [X1-010](x1-010.md)
- [Y8950, YM3526, YM3812, YMF262 and YMF278 (OPL)](opl.md)
- [ESFM](esfm.md)
- [VRC7 and YM2413 (OPLL)](opll.md)
- [YM2414 (OPZ)](opz.md)
- [YM2151 (OPM)](ym2151.md)
- [YM2203 (OPN)](ym2203.md)
- [YM2608 (OPNA)](ym2608.md)
- [YM2610 (OPNB)](ym2610.md)
- [YM2610B (OPNB2)](ym2610b.md)
- [YM2612/YM3438 (OPN2)](ym2612.md)
- [YMZ280B](ymz280b.md)
- [ZX Spectrum Beeper](zxbeep.md)

Furnace also reads .dmf files with the [Yamaha YMU759](ymu759.md) system, but...
